@@ -8,11 +8,14 @@ $VERSION = sprintf "%d.%02d%02d", q/0.1.2/ =~ /(\d+)/g;
 
 %Mail::Mbox::MessageParser::Config = (
   'programs' => {
-    'bzip' => 'bzip2',
+    'bzip' => '/usr/local/bin/bzip2',
     'bzip2' => '/usr/local/bin/bzip2',
+    'cat' => '/bin/cat',
     'diff' => '/usr/bin/diff',
     'grep' => undef,
     'gzip' => '/usr/bin/gzip',
+    'lzip' => 'lzip',
+    'xz' => '/usr/local/bin/xz',
   },
 
   'max_testchar_buffer_size' => 1048576,
